package Task::BeLike::MRUIZ;
{
  $Task::BeLike::MRUIZ::VERSION = '0.01';
}

use strict;
use warnings;



1;

__END__

=pod

=head1 NAME

Task::BeLike::MRUIZ - Perl modules MRUIZ likes to use

=head1 AUTHOR

=over 4

=item *
Miquel Ruiz <mruiz@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Miquel Ruiz.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
